
<!---
FrozenIsBool True
-->

##Example

We can set automatically dict that are wrapped into instances if 
the suffix str is recognized. Note tha you can force the thing to be setted even
if the SuffixStr doesn't correspond to the setted type with the _TypeBool=False